@@ -18,7 +18,7 @@ import mlflow
 
 def IfRunInAzureML():
     try:
-        run = Run.get_context()
+        run = Run.get_context(allow_offline=False)
         print('runrun')
         print(run)
     except:
@@ -42,9 +42,12 @@ def RegisterModel(model_path, description, args):
                         'apiVersion':args.apiVersion,
                         'subscriptionId':args.subscriptionId})
     else:
+        print('run on MLflow')
         mlFlowRun = mlflow.active_run()
+        print(mlFlowRun)
         if mlFlowRun:
             model_uri = "runs:/{run_id}/{artifact_path}".format(run_id=mlFlowRun.info.run_id, artifact_path=model_path)
+            print(model_uri)
             result = mlflow.register_model(
                 model_uri,
                 args.modelId
